<?php
 
/**
 * Plugin Name: Dimona ePrint Shipping
 * Plugin URI: https://eprint.dimona.com.br
 * Description: Dimona ePrint Shipping Method for WooCommerce
 * Version: 1.1.0
 * Author: Dimona ePrint
 * License: GPL-3.0+
 * Based on: https://code.tutsplus.com/tutorials/create-a-custom-shipping-method-for-woocommerce--cms-26098
 */
 
if ( ! defined( 'WPINC' ) ) {
 
    die;
 
}
 
/*
 * Check if WooCommerce is active
 */
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
 
    function eprint_shipping_method() {
        if ( ! class_exists( 'Eprint_Shipping_Method' ) ) {
            class Eprint_Shipping_Method extends WC_Shipping_Method {
                /**
                 * Constructor for your shipping class
                 *
                 * @access public
                 * @return void
                 */
                public function __construct() {
                    $this->id                 = 'eprint'; 
                    $this->method_title       = __( 'Frete Dimona ePrint', 'eprint' );  
                    $this->method_description = __( 'Cálculo de Frete Dinâmico Dimona ePrint', 'eprint' ); 
 
                    // Availability & Countries
                    $this->availability = 'including';
                    $this->countries = array(
                        'BR', // Unites States of America
                        );
 
                    $this->init();
 
                    $this->enabled = isset( $this->settings['enabled'] ) ? $this->settings['enabled'] : 'yes';
                    $this->title = isset( $this->settings['title'] ) ? $this->settings['title'] : __( 'Eprint Shipping', 'eprint' );
                }
 
                /**
                 * Init your settings
                 *
                 * @access public
                 * @return void
                 */
                function init() {
                    // Load the settings API
                    $this->init_form_fields(); 
                    $this->init_settings(); 
 
                    // Save settings in admin if you have any defined
                    add_action( 'woocommerce_update_options_shipping_' . $this->id, array( $this, 'process_admin_options' ) );
                }
 
                /**
                 * Define settings field for this shipping
                 * @return void 
                 */
                function init_form_fields() { 
 
                    $this->form_fields = array(
 
                     'enabled' => array(
                          'title' => __( 'Habilitado', 'eprint' ),
                          'type' => 'checkbox',
                          'description' => __( 'Habilitar o cálculo de frete ePrint', 'eprint' ),
                          'default' => 'yes'
                          ),
 
                     'title' => array(
                        'title' => __( 'Title', 'eprint' ),
                          'type' => 'text',
                          'description' => __( 'Nome que vai aparecer para os seus clientes', 'eprint' ),
                          'default' => __( 'Transportadora', 'eprint' )
                          ),
 
                     'apikey' => array(
                        'title' => __( 'Dimona API Key', 'eprint' ),
                          'type' => 'text',
                          'description' => __( 'Sua chave de API', 'eprint' ),
                          'default' => ''
                          ),
 
                     );
 
                }
 
                /**
                 * This function is used to calculate the shipping cost. Within this function we can check for weights, dimensions and other parameters.
                 *
                 * @access public
                 * @param mixed $package
                 * @return void
                 */
                public function calculate_shipping( $package = array() ) {
                    
                    $cost = 0;
                    $quantity = 0;
                    $zipcode = $package["destination"]["postcode"];
                    
                    foreach ( $package['contents'] as $item_id => $values ) 
                    { 
                        $quantity += $values['quantity'];
                    }

                    $response = wp_remote_post( "https://camisadimona.com.br/api/v2/shipping", array(
                          'method' => 'POST',
                          'timeout' => 45,
                          'redirection' => 5,
                          'httpversion' => '1.0',
                          'blocking' => true,
                          'headers' => array( "api-key"=>$this->settings["apikey"] , "Accept"=>"application/json", "Content-Type"=>"application/json"),
                          'body' => json_encode(array( 'zipcode' => $zipcode, 'quantity' => $quantity )),
                          'data_format' => 'body'
                        )
                    );

                    if ( is_wp_error( $response ) ) {
                       $error_message = $response->get_error_message();
                       die("Something went wrong: $error_message");
                    } else {

                      $body = json_decode($response['body']);
                      if(isset($body->errors))
                      {
                        return;
                      }
                      
                       $cost = $body[0]->value;
                       $business_days = $body[0]->business_days;
                        $rate = array(
                          'id' => $this->id,
                          'label' => $this->title . " $business_days dias úteis",
                          'cost' => $cost
                      );

                      $this->add_rate( $rate );
                    }
                }
            }
        }
    }
 
    add_action( 'woocommerce_shipping_init', 'eprint_shipping_method' );
 
    function add_eprint_shipping_method( $methods ) {
        $methods[] = 'Eprint_Shipping_Method';
        return $methods;
    }
 
    add_filter( 'woocommerce_shipping_methods', 'add_eprint_shipping_method' );
 
    function eprint_validate_order( $posted )   {
        //Aqui podemos validar se o endereço de entrega é no Brasil
    }
 
    add_action( 'woocommerce_review_order_before_cart_contents', 'eprint_validate_order' , 10 );
    add_action( 'woocommerce_after_checkout_validation', 'eprint_validate_order' , 10 );
}